==> pecl-intl-1.0.0.tbz: include/php/ext/intl/php_intl.h <==
/*
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Vadim Savchuk <vsavchuk@productengine.com>                  |
   |          Dmitry Lakhtyuk <dlakhtyuk@productengine.com>               |
   |          Stanislav Malyshev <stas@zend.com>                          |
   |          Kirti Velankar <kirtig@yahoo-inc.com>                       |
   +----------------------------------------------------------------------+
 */

#ifndef PHP_INTL_H
#define PHP_INTL_H

#include <php.h>

#include "collator/collator_sort.h"
#include "grapheme/grapheme.h"
#include "intl_error.h"

extern zend_module_entry intl_module_entry;
#define phpext_intl_ptr &intl_module_entry

#ifdef PHP_WIN32
#define PHP_INTL_API __declspec(dllexport)
#else
#define PHP_INTL_API
#endif

#ifdef ZTS
#include "TSRM.h"
#endif

ZEND_BEGIN_MODULE_GLOBALS(intl)
	zval* current_collator;
	char* default_locale;
	collator_compare_func_t compare_func;
	UBreakIterator* grapheme_iterator;
	intl_error g_error;
ZEND_END_MODULE_GLOBALS(intl)

/* Macro to access request-wide global variables. */
#ifdef ZTS
#define INTL_G(v) TSRMG(intl_globals_id, zend_intl_globals *, v)
#else
#define INTL_G(v) (intl_globals.v)
#endif

ZEND_EXTERN_MODULE_GLOBALS(intl)

PHP_MINIT_FUNCTION(intl);
PHP_MSHUTDOWN_FUNCTION(intl);
PHP_RINIT_FUNCTION(intl);
PHP_RSHUTDOWN_FUNCTION(intl);
PHP_MINFO_FUNCTION(intl);

#define PHP_INTL_VERSION "1.0.0RC1"

#endif  /* PHP_INTL_H */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */

==> pecl-intl-1.1.1.tbz: include/php/ext/intl/php_intl.h <==
/*
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Vadim Savchuk <vsavchuk@productengine.com>                  |
   |          Dmitry Lakhtyuk <dlakhtyuk@productengine.com>               |
   |          Stanislav Malyshev <stas@zend.com>                          |
   |          Kirti Velankar <kirtig@yahoo-inc.com>                       |
   +----------------------------------------------------------------------+
 */

#ifndef PHP_INTL_H
#define PHP_INTL_H

#include <php.h>

#include "collator/collator_sort.h"
#include "grapheme/grapheme.h"
#include "intl_error.h"

extern zend_module_entry intl_module_entry;
#define phpext_intl_ptr &intl_module_entry

#ifdef PHP_WIN32
#define PHP_INTL_API __declspec(dllexport)
#else
#define PHP_INTL_API
#endif

#ifdef ZTS
#include "TSRM.h"
#endif

ZEND_BEGIN_MODULE_GLOBALS(intl)
	zval* current_collator;
	char* default_locale;
	collator_compare_func_t compare_func;
	UBreakIterator* grapheme_iterator;
	intl_error g_error;
	long error_level;
ZEND_END_MODULE_GLOBALS(intl)

/* Macro to access request-wide global variables. */
#ifdef ZTS
#define INTL_G(v) TSRMG(intl_globals_id, zend_intl_globals *, v)
#else
#define INTL_G(v) (intl_globals.v)
#endif

ZEND_EXTERN_MODULE_GLOBALS(intl)

PHP_MINIT_FUNCTION(intl);
PHP_MSHUTDOWN_FUNCTION(intl);
PHP_RINIT_FUNCTION(intl);
PHP_RSHUTDOWN_FUNCTION(intl);
PHP_MINFO_FUNCTION(intl);

#define PHP_INTL_VERSION "1.0.3"

#endif  /* PHP_INTL_H */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
